register

Function register 

pub async fn register(
    __arg0: State<State>,
    __arg1: Json<RegisterRequest>,
) -> Result<StatusCode>
Registers a new user with the provided credentials.

Errors

  • Returns a BadRequest if the identity hash cannot be decoded from hex.
  • Returns a Conflict if a user with the same identity hash already exists.
  • Returns an internal error if a database query fails.