pub async fn register(
__arg0: State<State>,
__arg1: Json<RegisterRequest>,
) -> Result<StatusCode>Expand description
Registers a new user with the provided credentials.
Errors
- Returns a
BadRequestif the identity hash cannot be decoded from hex. - Returns a
Conflictif a user with the same identity hash already exists. - Returns an internal error if a database query fails.